use strict;
use warnings;

use Test::More tests => 4;

use_ok( 'App::FileSummoner' );
use_ok( 'App::FileSummoner::CreateFile' );
use_ok( 'App::FileSummoner::Register' );
use_ok( 'App::FileSummoner::SkeletonDirsFinder' ); 

